@@ -89,7 +89,8 @@ public:
 	    *enviCova,//!< QAction ENVI only for covalent contacts
 	    *wireButt,//!< QAction show atoms while rotation in wire mode
 	    *invSelection,//!< QAction invert selection
-            *hideBeLo;//!< hide/show  BEDE and LONE objects
+            *hideBeLo,//!< hide/show  BEDE and LONE objects
+            *atomLegend;//!< a key legend for atoms used
     QToolButton *enviButt;//!< Button to clear the envi -ronment.
     QToolButton *enviSelect;//!< Button to select the envi -ronment.
     QList<V3>enviPositions;//!<List of atom postions of an envi-ronment.
