@@ -8,7 +8,7 @@
  ----------------------------------------------------------------------------
 */
 
-
+//#include "bits/stdc++.h"
 #include <QtGui>
 #include <QDir>
 #include <QNetworkAccessManager>
@@ -18,7 +18,7 @@
 #include "dsreditwindow.h"
 #include "itsme.h"
 
-#ifdef Q_WS_WIN32
+#if defined(Q_OS_WIN) || defined(Q_WS_WIN32)
    static const QString mysystem = "win";
 #else
    static const QString mysystem = "unix";
@@ -260,7 +260,7 @@ DSRGui::DSRGui(Molecule *mole, QString shelxlPath, Window *parent): QWidget(pare
   QItemSelectionModel *sm = fragmentTableView->selectionModel();
   this->move(m_shelxle->width()-this->width()-30, 30);
   this->show();
-  if (!(sm == 0x0)){  // prevents error about missing connection if DSR is not present
+  if (!(sm == NULL)){  // prevents error about missing connection if DSR is not present
     connect(sm, SIGNAL(currentRowChanged(QModelIndex,QModelIndex)),
         this, SLOT(setFragName(QModelIndex)), Qt::UniqueConnection);
   }
@@ -439,7 +439,7 @@ void DSRGui::isDSRUpToDate(QNetworkReply* reply) {
   }
   reply->close();
   reply->deleteLater();
-  disconnect(net_manager, SIGNAL(finished(QNetworkReply*)), 0, 0);
+  disconnect(net_manager, SIGNAL(finished(QNetworkReply*)), NULL, NULL);
 }
 
 void DSRGui::updateTarget() {
@@ -482,9 +482,17 @@ QStringList DSRGui::which(QString programName) {
   foundInPath.clear();
   execlist.clear();
   if (mysystem == "win") {
-    pathList = QString(qgetenv("PATH").constData()).split(";");
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
+    pathList = QString(qEnvironmentVariable("PATH")).split(";");
+#else
+    pathList = QString(qgetenv("PATH")).split(";");
+#endif
   } else {
-    pathList = QString(qgetenv("PATH").constData()).split(":");
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
+    pathList = QString(qEnvironmentVariable("PATH")).split(":");
+#else
+    pathList = QString(qgetenv("PATH")).split(":");
+#endif
   }
   execlist << ".bat" << ".exe" << "";
   foreach (QString exec, execlist) {
@@ -732,7 +740,11 @@ QString DSRGui::findFreeResiNumber() {
     }
   }
   resilist = resiset.toList();
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
+  std::sort(resilist.begin(), resilist.end());
+#else
   qSort(resilist);
+#endif
   int count = 0;
   foreach (int num, resilist) {
     if (num != count) {
@@ -874,7 +886,11 @@ int DSRGui::getCharWidth(int numchars) {
   for (int i=1; i<=numchars; i++) {
     buchstaben += "#";
   }
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
+  return QFontMetrics(this->font()).horizontalAdvance(buchstaben);
+#else
   return QFontMetrics(this->font()).width(buchstaben);
+#endif
 }
 
 
@@ -937,7 +953,7 @@ void DSRGui::combineOptionstext(void) {
     }
   } else {
     if (target_atoms.split(" ").length() != 1) {
-      target_atoms = "<font color=red> Please select <b>one</b> carbon atom! </font>";
+      target_atoms = "<font color=red> Please select only <b>a single</b> carbon atom! </font>";
     }
     mygl->source_atoms = "";
   }
@@ -1327,7 +1343,7 @@ bool DSRGui::runDSR(QString option, bool showresults, QString workdir) {
   if (workdir.isEmpty()) {
     // workdir can be the export (fragment) directory for example.
     resfip.setFile(m_shelxle->dirName);
-    if (!resfip.absolutePath().isEmpty()) {
+    if (resfip.exists()) {
       // Need to check if path is not empty, because en empty path would cause dsr.start() to fail.
       // absolutePath() truncates the last path part even though its C:\foo\bar --> C:\foo
       dsr.setWorkingDirectory(resfip.absolutePath());
@@ -1514,16 +1530,26 @@ void DSRGui::displayFragmentsList(QVector<QStringList> list, QString fav="None")
 QString DSRGui::getDSRDir() {
   //! returns the value of the DSR_DIR variable
   //! in case of error, it returns an empty string
-  QString dsrdir = qgetenv("DSR_DIR").data();
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
+  QString dsrdir = qEnvironmentVariable("DSR_DIR");
+#else
+  QString dsrdir = qgetenv("DSR_DIR");
+#endif
   if (!QFile::exists(dsrdir)){
     if (!which("dsr").isEmpty()) {
       QFileInfo fi(which("dsr").at(0));
-      dsrdir = fi.absolutePath();
+      if (fi.exists()) {
+        dsrdir = fi.absolutePath();
+      }
     }
     if (QFile::exists("/Applications/DSR")) {
         dsrdir = "/Applications/DSR";
     }
-    QString dsrdir2 = qgetenv("DSRDIR").data();
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
+    QString dsrdir2 = qEnvironmentVariable("DSRDIR");
+#else
+    QString dsrdir2 = qgetenv("DSRDIR");
+#endif
     if (QFile::exists(dsrdir2)) {
       qDebug() << "You are probably using an older version of DSR."
                   "\n Please use version 1.7.7 or above.";
