@@ -52,7 +52,7 @@ FourXle::FourXle(Molecule *mole_, ChGL *chgl_,QToolBar *toolView, double resol,
   chgl->foact->setVisible(false);
   doMaps = new QCheckBox("Calculate Maps");
   doMaps->setChecked(true);
-
+  connect(chgl,SIGNAL(destroyed(QObject*)),this,SLOT(chglDestroyed()));
   char *ENUS=setlocale(LC_ALL,"C");
   if (!ENUS)ENUS=setlocale(LC_ALL,"en_US.UTF-8"); 
   //printf("%s\n",ENUS);
@@ -66,8 +66,8 @@ FourXle::~FourXle(){
 void FourXle::killmaps(){
   /*! deletes all fourier maps and frees the memory
    */
-  if (chgl->fofcact!=NULL) chgl->fofcact->setVisible(false);
-  if (chgl->foact!=NULL) chgl->foact->setVisible(false);
+  if ((chgl!=NULL)&&(chgl->fofcact!=NULL)) chgl->fofcact->setVisible(false);
+  if ((chgl!=NULL)&&(chgl->foact!=NULL)) chgl->foact->setVisible(false);
   if (datfo!=NULL) free(datfo);
   if (datfo_fc!=NULL) free(datfo_fc);
   datfo=datfo_fc=NULL;
@@ -77,9 +77,9 @@ void FourXle::killmaps(){
   if (nodez!=NULL) free(nodez);
   if (noGoMap!=NULL) free(noGoMap);
   nodex=nodey=nodez=NULL;noGoMap=NULL;
-  disconnect(chgl,SIGNAL(diffscroll(int ,int )),0,0);
-  disconnect(chgl,SIGNAL(neuemitte(V3)),0,0);
-  disconnect(chgl,SIGNAL(inimibas()),0,0);
+  if (chgl!=NULL) disconnect(chgl,SIGNAL(diffscroll(int ,int )),0,0);
+  if (chgl!=NULL) disconnect(chgl,SIGNAL(neuemitte(V3)),0,0);
+  if (chgl!=NULL) disconnect(chgl,SIGNAL(inimibas()),0,0);
 
 }
 
@@ -449,7 +449,7 @@ void FourXle::deleteLists(){
   /*! deletes the display lists of the fourier maps.
    */
  for (int fac=0; fac<18; fac++){
-    if ((chgl->foubas[fac])&&(glIsList(chgl->foubas[fac]))) {
+    if ((chgl!=NULL)&&(chgl->foubas[fac])&&(glIsList(chgl->foubas[fac]))) {
       //printf("deleting list %d %d %d\n", chgl->foubas[fac], glIsList(chgl->foubas[fac]),fac);
       glDeleteLists(chgl->foubas[fac],1);
       chgl->foubas[fac]=0;
@@ -1122,11 +1122,17 @@ void FourXle::change_iso(int numsteps,int diff){
 }
 
 void FourXle::foactDestroyed() {
-  chgl->foact = NULL;
+  if (chgl!=NULL) chgl->foact = NULL;
 }
 
 void FourXle::fofcactDestroyed() {
-  chgl->fofcact = NULL;
+  if (chgl!=NULL)chgl->fofcact = NULL;
+}
+
+void FourXle::chglDestroyed() {
+    fprintf(stderr,"chgl is dead omg ...argh...\n");
+
+    chgl = NULL;
 }
 
 void FourXle::CalcVertex( int ix, int iy, int iz) {
