@@ -15,7 +15,7 @@ ListFileHandler::ListFileHandler(QString lfpath, QObject *parent) : QObject(pare
   REL_RESTR_CARDS << "SAME"<< "SADI"<< "SIMU"<< "RIGU"<< "ISOR"<< "NCSY"<< "FLAT" << "DELU";
   my_lstpath = lfpath;
   //QFileSystemWatcher fw;  // The filesystem watcher doesn't work in my windows 8.1
-  //fw.addPath(*my_lstpath);  // I am not shure why I added it? It works also without
+  //fw.addPath(*my_lstpath);  // I am not shure why I added it? It works also without. DK
   success = false; // turns to true if refinement was a sucess.
   listfcontent = new QStringList;
   listfcontent->append(this->loadLst());
@@ -469,6 +469,7 @@ void XLOutputParser::fillListFileData(QString line) {
 QString XLOutputParser::residualsTextDisplay(QString &line, int ls_cycles) {
   //! returns a html string to display the refinement results in a QLabel
   fillListFileData(line);
+  QString html_output = "";
   QString html_final = "";
   QString wr2line = "";
   QString shiftyellow = "";
@@ -491,15 +492,23 @@ QString XLOutputParser::residualsTextDisplay(QString &line, int ls_cycles) {
           .arg(listf_data.holefrom)       // 8
           .arg(listf_data.R1_all.toDouble()*100, 4, 'f', 2, 0)       // 9
         ;
+    // One of flack or parson exists:
     if (!listf_data.flack.isEmpty() || !listf_data.parson.isEmpty()) {
-      if (!listf_data.parson.isEmpty()) {
-        wr2line = QString("<tr><td align=right> <b>Flack X </b>= </td> <td> %1 (Parsons' method)</td> "
-                           "<td>  </td> </tr>").arg(listf_data.parson);
+      // both exist:
+      if (!listf_data.flack.isEmpty() && !listf_data.parson.isEmpty()) {
+        wr2line = QString("<tr><td align=right> <b>Flack X </b>= </td> <td> %1 (Parsons' method)</td> <td>  </td> </tr> "
+                          "<tr><td align=right> </td> <td> %2 (classical fit)</td> <td>  </td> </tr>").arg(listf_data.parson).arg(listf_data.flack);
       }
-      if (!listf_data.flack.isEmpty()) {
+      // Only classical exists:
+      if (!listf_data.flack.isEmpty() && listf_data.parson.isEmpty()) {
         wr2line = QString("<tr><td align=right> <b>Flack X </b>= </td> <td> %1 (classical fit)</td> "
                                   "<td>  </td> </tr>").arg(listf_data.flack);
       }
+      // Only Parsons exists:
+      if (!listf_data.parson.isEmpty() && listf_data.flack.isEmpty()){
+        wr2line = QString("<tr><td align=right> <b>Flack X </b>= </td> <td> %1 (Parsons' method)</td> "
+                           "<td>  </td> </tr>").arg(listf_data.parson);
+      }
     } else { // no flack parameter:
       wr2line = ""; // No Table row to prevent empty line
     }
@@ -529,7 +538,7 @@ QString XLOutputParser::residualsTextDisplay(QString &line, int ls_cycles) {
         .arg(ls_cycles);       // 1
     progressbar = QString("<td bgcolor=#69CB3F>%1</td>").arg(QString("&nbsp;").repeated(repeat)).repeated(10);
   }
-  QString html_output = QString(
+  html_output = QString(
         "<body style=\"font-family:SansSerif; font-size:11pt;\">"
         "<H2>Running SHELXL %1</H2> "
         "<table cellpadding=3% align=left>"
@@ -637,9 +646,10 @@ QString XLOutputParser::xl_cmdline(QString line) {
 }
 
 QStringList XLOutputParser::xl_current_wr2_data_param(QString line) {
-  //! Returns the number of data (reflections)
-  //! shelxl is refinimg against. This is without sigma cutoff.
+  //! Returns the number of data (reflections) shelxl is refining against.
+  //! This is without sigma cutoff:
   //! " wR2 = 0.4016 before cycle   1 for   10786 data and    737 /    737 parameters"
+  //! returns list of [wR2, cycles, data, current_parameters, all_parameters]
   QStringList linesplit;
   QString wr2 = "";
   QString cycle = "";
