@@ -23,8 +23,8 @@
 void mh(QtMsgType type, const QMessageLogContext &context, const QString &msg) {
   QByteArray localMsg = msg.toLocal8Bit();
     QString pth=QDir::homePath()+"/ShelXle_message.txt";
-    FILE *er=fopen(pth.toStdString().c_str(),"wt");
-    fprintf(er,"======\n%s\n======\n",localMsg.constData());
+    FILE *er=fopen(pth.toStdString().c_str(),"at");
+    fprintf(er,"======%s\n%s\n======\n",QDateTime::currentDateTime().toString().utf16(),localMsg.constData());
     fclose(er);
     if (strstr(localMsg.constData(),"QGLShader::link:")!=NULL) {
       printf("%s\n",localMsg.constData());fflush(stdout);
