@@ -1240,7 +1240,8 @@ public:
   CEnvironment asymm,//!< atom list containing the asymertic unit 
 	       showatoms,//!< atom list containing all atoms to be drawn.
 	       selectedatoms,//!< atom list of selected atoms.
-	       duplicateAtoms;//!< atom list of identcal labeled atoms.
+	       duplicateAtoms,//!< atom list of identcal labeled atoms.
+               legendAtoms;//!< Atoms in a key legend.
   Connection showbonds;//!< list of visible bonds.
   Connection lbonds;//!< list of line bonds (for Q-Peaks)
   QStringList usedSymmetry;//!< List of internal symmetry codes of symmetry operations curently applied.
