@@ -107,6 +107,7 @@ public slots:
   void addMethyl();//!<Adds hydroghen atoms to a R-C carbon atom. (methyl group) AFIX 137.
   void addMoreQPeaks();//!<Creates Q-Peaks from the Fo-Fc map.
   void autoHFix();//!<Automatically adds H atoms and AFIX instructions to the file uses the Fo-Fc map. 
+  void brwsIcon();//!< Select an alternative icon for external program
   void changeFixes(int i);//!< Variable that should not be refined get a 10 added.
   void changeEditorFont();//!<Changes the Editor font via an font dialog.
   void changeElemetofLabel(const QString &pse);//!<NextLabel of rename mode consists of labelPSE labelIndex labelSuffix, this changes the LabelPSE to pse. @param pse next labelPSE. 
@@ -194,6 +195,7 @@ public slots:
   void jnk();//!< Julian Henn and Kathrin Meindl frcatal dimension analisis
   void jumpToAtom(int index);//!< if rename mode is visible the atom at index gets renamed if not the cursor of the editor is pointed to the specified atom.
   void jumpToError();//!< the cursor points to the first syntax error in the file.
+  void killFourXleFirst();//!< attempt to run killmaps before chgl gets destryed
   void linkHelp();//!< Show a Link to the online help. 
   void loadAFile();//!< (re)loads the file specified in dirName.
   void loadFile(QString fileName);//!< loads the file with the specified path the listfile is also loaded. @param fileName path to the res / ins file.
@@ -244,6 +246,7 @@ public slots:
   void setShelxlOptions();//!< sets path and command line options for ShelXl executable.
   void setShelxlPath();//!< sets path for ShelXl executable
   void setExtraPath();//!<sets path for an external program
+  void updateExtraIcon();//!< redraws the icon preview
   void setSDMLimit();//!< max atoms in au to skip sdm calculation
   void setMonoQ(bool vis);//!<sets monochome modus for Q-Peaks to vis @param vis mochrome mode of Q-Peaks.
   void showSearch();//!< shows the search and repleace for the editor.
@@ -279,6 +282,7 @@ public slots:
   void updateXLput();//!< the output view for the shelxl run is updated
   void updateExtraOutput();//!< the output view for the external program is updated.
   void updateExtraSettings(int index);//!< the external programs dialog gets updated.
+  void updateExtraSettings();//!< the external programs dialog gets updated.
   void wasDelete();//!< for undo redo fuctionality of atom deletion.
   void wasRename();//!< for undo redo fuctionality of atom renameing. 
   void withdrawres();//!< discard the results of the refinement. Copies back the ins file to the res file and loads that.  
@@ -385,8 +389,14 @@ private:
   QString unitAlt, unitNeu, shelxlPath, shelxlArgs;
   bool useMyBArray;    //! If set to true, the b-array is not automatically set by ShelXle
   QStringList extraProgramNames,extraProgramPaths,extraOptions,extraExt2;
-  QList<Qt::CheckState>  extraArguments,extraExtensions, extraDetach, extraResIns;
+  QList<Qt::CheckState>  extraArguments,extraExtensions, extraDetach, extraResIns, extraOpenFileDialogBefore, extraIconOverlay;
   QLineEdit *extraPath,*extraName,*extraAltExtEdit,*extraArgumentsEdit,*shxPath,*shxOptions;
+  QList<int> extraOverlayPointSize;
+  QSpinBox *iovlPointSize;
+  QComboBox *pgms;
+  QToolButton *extraFakeButton;
+  QString altExtraIconPath;
+  QStringList altExtraIconPaths;
   QDockWidget *helpDock;
 //  QWebView *hilfe;
   //QTextBrowser *hilfe;
@@ -435,6 +445,8 @@ private:
   QCheckBox *omitExtension;
   QCheckBox *detach;
   QCheckBox *copyResIns; 
+  QCheckBox *openFileDialogBefore; 
+  QCheckBox *iconOverlay;
   QSize ediSize;
   QPoint ediPos;
   QComboBox *resiFinder;
